==> cms-db_v0.7.11.tar.gz: admin/changepw.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('changepw');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<?php
if (isset($_POST['button'])) {
	$file = $_SESSION['CMS-User'];
	include('../data/users/'.$file);
	if (sha1($file.$_POST['oldpass']) == $pass && $_POST['pass'] == $_POST['repeat']) {
		include('escape.inc.php');
		$pass = sha1($file.escapeSL($_POST['pass']));
		$writethis = '<?php
		$user = \''.escapeSave($user).'\';
		$pass = \''.escapeSave($pass).'\';
		$user_pages = \''.escapeSave($pages).'\';
		$user_files = \''.escapeSave($files).'\';
		$user_includes = \''.escapeSave($includes).'\';
		$user_template = \''.escapeSave($template).'\';
		$user_gbook = \''.escapeSave($gbook).'\';
		$user_stats = \''.escapeSave($stats).'\';
		?>';
		file_put_contents('../data/users/'.$_SESSION['CMS-User'], $writethis);
		echo '<h1>'.locale('title_settings-saved',true) .'</h1>';
		echo '<p>'.locale('desc_settings-saved',true).'</p>';
	} else {
		echo '<h1>'.locale('title_error',true) .'</h1>';
		echo '<p>'.locale('desc_error-invalid-data',true).'</p>';
		echo '<p><a href="changepw.php?'.SID.'">'.locale('link_back',true).'</a></p>';
	}
} else {
?>

<h1><?php locale('title') ?></h1>
<p>
	<form action="changepw.php?<?php echo SID ?>" method="POST">
		<?php locale('label_oldpw') ?> <input type="password" name="oldpass" value="" /><br />
		<?php locale('label_newpw') ?> <input type="password" name="pass" value="" /><br />
		<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
		<input type="submit" name="button" value="<?php locale('button_save') ?>">
	</form>
</p>
<p>
	<a href="enforcesettings.php?<?php echo SID ?>"><?php locale('link_global-settings') ?></a>
</p>

<?php
}
?>

</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/changepw.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('changepw');

$message = '';
if (isset($_POST['button'])) {
	$file = $_SESSION['CMS-User'];
	include('../data/users/'.$file);
	if (sha1($file.$_POST['oldpass']) == $pass && $_POST['pass'] == $_POST['repeat']) {
		include('escape.inc.php');
		$pass = sha1($file.escapeSL($_POST['pass']));
		$writethis = '<?php
		$user = \''.escapeSave($user).'\';
		$pass = \''.escapeSave($pass).'\';
		$user_pages = \''.$user_pages.'\';
		$user_files = \''.$user_files.'\';
		$user_includes = \''.$user_includes.'\';
		$user_template = \''.$user_template.'\';
		$user_gbook = \''.$user_gbook.'\';
		$user_gbook = \''.$user_blog.'\';
		$user_stats = \''.$user_stats.'\';
		?>';
		file_put_contents('../data/users/'.$_SESSION['CMS-User'], $writethis);
		$message = '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
	} else {
		$message = '<p class="error">'.locale('desc_error-invalid-data',true).'</p>';
		$error = true;
	}
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title') ?></h1>

<?php echo $message; ?>

<p>
	<form action="changepw.php?<?php echo SID; csrf_protection_get_html() ?>" method="POST">
		<?php locale('label_oldpw') ?> <input type="password" name="oldpass" value="" /><br />
		<?php locale('label_newpw') ?> <input type="password" name="pass" value="" /><br />
		<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
		<input type="submit" name="button" value="<?php locale('button_save') ?>">
	</form>
</p>
<p>
	<a href="enforcesettings.php?<?php echo SID; csrf_protection_get_html() ?>"><?php locale('link_global-settings') ?></a>
</p>

</body>
</html>
